endState property
Footer shown below the grid once everything has loaded (!hasMore) and the
feed is non-empty (source endState).
Implementation
final Widget? endState;
Footer shown below the grid once everything has loaded (!hasMore) and the
feed is non-empty (source endState).
final Widget? endState;