BeuiPromptAction class

One entry in the BeuiPromptInput actions popover (attach image, skill…).

Mirrors the source's PromptAction.

Annotations

Constructors

BeuiPromptAction({required String value, required String label, String? description, Widget? icon, bool enabled = true})
Creates an action entry.
const

Properties

description → String?
Optional secondary description under label.
final
enabled → bool
Whether the action can be chosen.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
Optional leading glyph.
final
label → String
Primary label.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
Stable value committed via BeuiPromptInput.onAction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited